==> dda-managed-vm-2.2.0.jar: dda/pallet/dda_managed_vm/infra/browser.clj <==
; Licensed to the Apache Software Foundation (ASF) under one
; or more contributor license agreements. See the NOTICE file
; distributed with this work for additional information
; regarding copyright ownership. The ASF licenses this file
; to you under the Apache License, Version 2.0 (the
; "License"); you may not use this file except in compliance
; with the License. You may obtain a copy of the License at
;
; http://www.apache.org/licenses/LICENSE-2.0
;
; Unless required by applicable law or agreed to in writing, software
; distributed under the License is distributed on an "AS IS" BASIS,
; WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
; See the License for the specific language governing permissions and
; limitations under the License.
(ns dda.pallet.dda-managed-vm.infra.browser
  (:require
   [schema.core :as s]
   [pallet.actions :as actions]))

(def Link [(s/one s/Str "url")  (s/one s/Str "name")])

(def Folder {:name s/Str
             (s/optional-key :links) [Link]
             (s/optional-key :childs) [(s/recursive #'Folder)]})

(def Bookmarks [Folder])

(def Settings
  "The browser settings"
  (hash-set
    :install-chromium))

(defn install-chromium []
  (actions/package "chromium-browser"))

(def header
  ["<!DOCTYPE NETSCAPE-Bookmark-file-1>"
   "<META HTTP-EQUIV=\"Content-Type\" CONTENT=\"text/html; charset=UTF-8\">"
   "<TITLE>Bookmarks</TITLE>"
   "<H1>Bookmarks Menu</H1>"
   "<DL><p>"])

(def tail
   ["</DL>"])

(s/defn indent :- s/Str
  [level :- s/Num]
  (apply str (take level (repeat "    "))))

(s/defn generate-single-link
 [level :- s/Num
  link :- Link]
 (str
   (indent level)
   "<DT><A HREF=\"" (first link) "\">" (second link) "</A>"))

(s/defn generate-single-folder
 [level :- s/Num
  folder :- Folder]
 (let [{:keys [name links childs]} folder
       toolbar-folder? (= "Bookmarks Toolbar" name)]
   (concat
      [(str
          (indent level)
          (if toolbar-folder?
            "<DT><H3 PERSONAL_TOOLBAR_FOLDER=\"true\">"
            "<DT><H3>")
          name "</H3>")
       (if (or links childs)
          [(str (indent level) "<DL><p>")]
          [])
       (if links
         (flatten (map (partial generate-single-link (+ 1 level)) links))
         [])
       (if childs
         (flatten (map (partial generate-single-folder (+ 1 level)) childs))
         [])
       (if (or links childs)
         [(str (indent level) "</DL><p>")]
         [])])))

(s/defn generate-bookmarks
  "generaters bookmarks html lines"
  [folders :- Bookmarks]
  (concat
    header
    (flatten (map (partial generate-single-folder 1) folders))
    tail))

(s/defn configure-user-bookmarks
  ""
  [user :- s/Str
   folders :- Bookmarks]
  (let [content (clojure.string/join
                  \newline
                  (generate-bookmarks folders))]
    (actions/remote-file
      (str "/home/" user "/bookmarks.html")
      :literal true
      :owner user
      :group user
      :content content)))

==> dda-managed-vm-2.2.1-20180723.160214-4.jar: dda/pallet/dda_managed_vm/infra/browser.clj <==
; Licensed to the Apache Software Foundation (ASF) under one
; or more contributor license agreements. See the NOTICE file
; distributed with this work for additional information
; regarding copyright ownership. The ASF licenses this file
; to you under the Apache License, Version 2.0 (the
; "License"); you may not use this file except in compliance
; with the License. You may obtain a copy of the License at
;
; http://www.apache.org/licenses/LICENSE-2.0
;
; Unless required by applicable law or agreed to in writing, software
; distributed under the License is distributed on an "AS IS" BASIS,
; WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
; See the License for the specific language governing permissions and
; limitations under the License.
(ns dda.pallet.dda-managed-vm.infra.browser
  (:require
   [schema.core :as s]
   [pallet.actions :as actions]
   [dda.config.commons.user-home :as user-env]))

(def Link [(s/one s/Str "url")  (s/one s/Str "name")])

(def Folder {:name s/Str
             (s/optional-key :links) [Link]
             (s/optional-key :childs) [(s/recursive #'Folder)]})

(def Bookmarks [Folder])

(def Settings
  "The browser settings"
  (hash-set
    :install-chromium))

(defn install-chromium []
  (actions/package "chromium-browser"))

(def header
  ["<!DOCTYPE NETSCAPE-Bookmark-file-1>"
   "<META HTTP-EQUIV=\"Content-Type\" CONTENT=\"text/html; charset=UTF-8\">"
   "<TITLE>Bookmarks</TITLE>"
   "<H1>Bookmarks Menu</H1>"
   "<DL><p>"])

(def tail
   ["</DL>"])

(s/defn indent :- s/Str
  [level :- s/Num]
  (apply str (take level (repeat "    "))))

(s/defn generate-single-link
 [level :- s/Num
  link :- Link]
 (str
   (indent level)
   "<DT><A HREF=\"" (first link) "\">" (second link) "</A>"))

(s/defn generate-single-folder
 [level :- s/Num
  folder :- Folder]
 (let [{:keys [name links childs]} folder
       toolbar-folder? (= "Bookmarks Toolbar" name)]
   (concat
      [(str
          (indent level)
          (if toolbar-folder?
            "<DT><H3 PERSONAL_TOOLBAR_FOLDER=\"true\">"
            "<DT><H3>")
          name "</H3>")
       (if (or links childs)
          [(str (indent level) "<DL><p>")]
          [])
       (if links
         (flatten (map (partial generate-single-link (+ 1 level)) links))
         [])
       (if childs
         (flatten (map (partial generate-single-folder (+ 1 level)) childs))
         [])
       (if (or links childs)
         [(str (indent level) "</DL><p>")]
         [])])))

(s/defn generate-bookmarks
  "generaters bookmarks html lines"
  [folders :- Bookmarks]
  (concat
    header
    (flatten (map (partial generate-single-folder 1) folders))
    tail))

(s/defn configure-user-bookmarks
  ""
  [user :- s/Str
   folders :- Bookmarks]
  (let [content (clojure.string/join
                  \newline
                  (generate-bookmarks folders))]
    (actions/remote-file
      (str (user-env/user-home-dir user) "/bookmarks.html")
      :literal true
      :owner user
      :group user
      :content content)))
